"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.regionToBBox = exports.isPointCluster = exports.getMarkersRegion = exports.getMarkersCoordinates = exports.coordsToGeoJSONFeature = void 0;

const calculateDelta = (x, y) => x > y ? x - y : y - x;

const calculateAverage = function () {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  const argList = [...args];

  if (!argList.length) {
    return 0;
  }

  return argList.reduce((sum, num) => sum + num, 0) / argList.length;
};

const regionToBBox = region => {
  const lngD = region.longitudeDelta < 0 ? region.longitudeDelta + 360 : region.longitudeDelta;
  return [region.longitude - lngD, // westLng - min lng
  region.latitude - region.latitudeDelta, // southLat - min lat
  region.longitude + lngD, // eastLng - max lng
  region.latitude + region.latitudeDelta // northLat - max lat
  ];
};

exports.regionToBBox = regionToBBox;

const getMarkersRegion = points => {
  const coordinates = {
    minX: points[0].latitude,
    maxX: points[0].latitude,
    maxY: points[0].longitude,
    minY: points[0].longitude
  };
  const {
    maxX,
    minX,
    maxY,
    minY
  } = points.reduce((acc, point) => ({
    minX: Math.min(acc.minX, point.latitude),
    maxX: Math.max(acc.maxX, point.latitude),
    minY: Math.min(acc.minY, point.longitude),
    maxY: Math.max(acc.maxY, point.longitude)
  }), { ...coordinates
  });
  const deltaX = calculateDelta(maxX, minX);
  const deltaY = calculateDelta(maxY, minY);
  return {
    latitude: calculateAverage(minX, maxX),
    longitude: calculateAverage(minY, maxY),
    latitudeDelta: deltaX * 1.5,
    longitudeDelta: deltaY * 1.5
  };
};

exports.getMarkersRegion = getMarkersRegion;

const getMarkersCoordinates = markers => {
  const [longitude, latitude] = markers.geometry.coordinates;
  return {
    longitude,
    latitude
  };
};
/**
 * Determines if a point is a cluster for `.properties` typesafe accessiblity
 * @param point ClusterFeature or PointFeature
 */


exports.getMarkersCoordinates = getMarkersCoordinates;

const isPointCluster = point => {
  return 'properties' in point && 'cluster' in point.properties;
};

exports.isPointCluster = isPointCluster;

/**
 * Utility function to convert coordinates to a GeoJSON feature
 * @param coords The coordinates to be converted to a GeoJSON feature - can be an array of two coordinates, `{ lat: number; lng: number }`, or `{ latitude: number; longitude: number }`
 * @param props Additional optional properties to be added to the feature
 */
const coordsToGeoJSONFeature = (coords, props) => {
  let coordinates;

  if (Array.isArray(coords)) {
    coordinates = coords;
  } else if ('latitude' in coords) {
    coordinates = [coords.longitude, coords.latitude];
  } else {
    coordinates = [coords.lng, coords.lat];
  }

  return {
    type: 'Feature',
    geometry: {
      coordinates,
      type: 'Point'
    },
    properties: props
  };
};

exports.coordsToGeoJSONFeature = coordsToGeoJSONFeature;
//# sourceMappingURL=utils.js.map